.. _introduction:

============
Introduction
============

Review Board is a tool for reviewing source code, documentation and other
text-based files. It offers a powerful web-based interface with broad browser
support for managing review requests and reviewing code, as well as command
line tools to simplify the review request submission process.

Review Board supports the following browsers:

* Firefox 3.0+
* Internet Explorer 9+
* Google Chrome


The following browsers are unsupported but known to work:

* Firefox 2.0
* Internet Explorer 8
* Opera 9+

Review Board is designed to fit in with existing :term:`pre-commit review`
and :term:`post-commit review` methods.
